@@ -44,17 +44,18 @@ __doc__ =   """
             >>> smod = stochpy.SSA()   # stochastic simulation algorithm module            
             >>> help(smod)
             >>> help(stochpy.SSA)      # (some windows versions)
+            >>> stochpy?
             >>> smod.DoStochSim()
             >>> cmod = stochpy.CellDivision()
             >>> cmod.DoCellDivisionStochSim() 
             >>> converter = stochpy.SBML2PSC()
-            >>> help(converter)
+            >>> converter?
             >>> help(stochpy.SBML2PSC) # (some windows versions)                        
             ...
             ...
             """
 
-__version__ = '1.0.7'
+__version__ = '1.0.9'
 
 import os,shutil,readline,sys
 
@@ -116,9 +117,9 @@ def InitiateModels(directory):
     models['dsmts-002-10.xml.psc'] = dsmts_002_10.model
     models['dsmts-003-03.xml.psc'] = dsmts_003_03.model
     models['dsmts-003-04.xml.psc'] = dsmts_003_03.model
-    models['OneNucleosome'] = OneNucleosome.model
-    models['TwoNucleosome'] = TwoNucleosome.model
-    models['ThreeNucleosome'] = ThreeNucleosome.model  
+    #models['OneNucleosome'] = OneNucleosome.model
+    #models['TwoNucleosome'] = TwoNucleosome.model
+    #models['ThreeNucleosome'] = ThreeNucleosome.model  
     models['chain5'] = chain5.model
     models['chain50'] = chain50.model
     models['chain500'] = chain500.model
@@ -212,18 +213,27 @@ def SaveInteractiveSession(filename='interactiveSession.py',path=output_dir):
     Input:
      - *filename*: [default = interactiveSession.py'] (string)
      - *path*: (string)
-    """    
+    """   
     historyPath = os.path.join(path,filename)
     if os.path.exists(path):
         readline.write_history_file(historyPath)
         file_in = open(historyPath,'r')
         history_list = file_in.readlines()
-        history_list.insert(0,'import stochpy\n')
+        n_import_statement = 0
+        for command in history_list:            
+            if 'import stochpy' in command:
+               n_import_statement +=1
+       
+        n = 0
         file_out = open(historyPath,'w')
-        for command in history_list[0:-1]:
-            file_out.write(command)
+        for command in history_list:
+            if "import stochpy" in command:             
+               n+=1
+            if n==n_import_statement:     
+                file_out.write(command)
+        file_out.close()
         print "Info: Interactive session successfully saved at", historyPath
-        print "Info: use 'ipython",filename+"' to restart modelling with this interactive session"        
+        print "Info: use 'ipython", filename+"' to restart modelling with this interactive session"        
     else:
         print "Error: directory does not exist" 
         
@@ -233,7 +243,7 @@ DeletePreviousOutput(temp_dir,'.xml')
 DeletePreviousOutput(temp_dir,'.txt')
 DeletePreviousOutput(temp_dir,'temp_parse_module')
 DeleteExistingData(temp_dir)
-readline.clear_history()
+#readline.clear_history()
 
 print """
 #######################################################################
