@@ -321,7 +321,26 @@ class SSA():
               self.SSA.propensities = copy.deepcopy(self.SSA.parse.propensities) 
           except Exception,er:
               print er
-              print "Parameters are: %s" % (self.SSA.parse.Mod.__pDict__.values())
+              print "Parameters are: %s" % (sorted(self.SSA.parse.Mod.__pDict__))
+      else:
+          print "Error: parameter = string and value = float"   
+
+  def ChangeInitialSpeciesAmount(self,species,value):
+      """
+      ChangeInitialSpeciesAmount(species,value)     
+      
+      Input:
+       - species (string)
+       - value (float)
+      """
+      if type(species) == str and (type(value) == float or type(value) == int):   
+          try:
+              self.SSA.parse.Mod.__sDict__[species]['initial'] = float(value)
+              self.SSA.parse.BuildX()     
+              self.SSA.X_matrixinit = copy.deepcopy(self.SSA.parse.X_matrix.transpose()[0])         
+          except Exception,er:
+              print er
+              print "Species are: %s" % (sorted(self.SSA.parse.Mod.__sDict__))
       else:
           print "Error: parameter = string and value = float"       
   
